@@ -352,7 +352,19 @@ static bool is_system_catalog(char *table_name)
 		 */
 		if (!relcache)
 		{
-			relcache = pool_create_relcache(128, ISBELONGTOPGCATALOGQUERY,
+			char *query;
+
+			/* pgpool_regclass has been installed */
+			if (pool_has_pgpool_regclass())
+			{
+				query = ISBELONGTOPGCATALOGQUERY2;
+			}
+			else
+			{
+				query = ISBELONGTOPGCATALOGQUERY;
+			}
+
+			relcache = pool_create_relcache(128, query,
 											int_register_func, int_unregister_func,
 											false);
 			if (relcache == NULL)
